% LaTeX definitions for SBC 2001 style
%
% Created by Jomi Hubner & Rafael Bordini, june 2001
% updated march 2005
% Modified on June 2005 by Norton Roman to comply with Faccamp standards

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{faccampq}[2013/01/08 Classe Latex para qualificação de mestrado]

%%%%%%%%%%%%%%%%DEFINIÇÕES GERAIS%%%%%%%%%%%%%%%%

% opções de codificação
\newcommand\@codificacao{}
\DeclareOption{latin1} {%
	\let\@codificacao\CurrentOption
}
\DeclareOption{utf8} {%
	% defino a codificação
	\let\@codificacao\CurrentOption
}

% Opções de língua
\newcommand\@lingua{}
\DeclareOption{brazilian} {%
	% defino a codificação
	\let\@lingua\CurrentOption
}
\DeclareOption{english} {%
	% defino a codificação
	\let\@lingua\CurrentOption
}

% Opções de imagens
\newcommand\@imagem{}
\DeclareOption{eps} {%
	% defino a codificação
	\let\@imagem\CurrentOption
}
\DeclareOption{outros} {%
	% defino a codificação
	\let\@imagem\CurrentOption
}

% opções padrão
\ExecuteOptions{utf8,brazilian,eps,a4paper}

% Executo o código das opções
\ProcessOptions

% Classe principal sobre a qual essa é construída (passo a ela os parâmetros de entrada, como letterpaper, por exemplo)
\LoadClassWithOptions{article}

% carrego o pacote para a codificação de caracteres
\RequirePackage[\@codificacao]{inputenc}

% carrego o pacote para a lingua escolhida
\RequirePackage[\@lingua]{babel}

% pacote para identação do primeiro parágrafo
\RequirePackage{indentfirst}

% para a manipulação de strings
%\RequirePackage{coolstr}

%%%%%%%%%%%%%%%%DEFINIÇÕES DE LAYOUT%%%%%%%%%%%%%%%%

% pacote para bibliografia estilo harvard
% \RequirePackage{harvard}


% margem sup 3.5 cm: há 1,5 cm para header, + 2 cm para top
% margem inf 2.5 cm: há 1,5 cm para foot, + 1 cm para bottom
% margem esq/dir 3 cm
% \RequirePackage[a4paper,top=3.5cm,left=3cm,right=3cm,bottom=2.5cm]{geometry}
\RequirePackage[a4paper,top=3.5cm,left=3cm,right=3cm,bottom=2.5cm]{geometry}

% acomoda o modelo de capa da faccamp, pressupondo impressão somente frente
\oddsidemargin 1cm % evensidemargin existe somente em book

\parindent 1.27cm
\parskip   6pt

\flushbottom

% captions
\RequirePackage[bf,sf,footnotesize,indent,labelsep=period]{caption}

\setlength{\captionmargin}{0.8cm}
\renewcommand{\captionfont}{\sffamily\footnotesize\bfseries}

% \setlength{\textwidth}{10cm}

% font
\RequirePackage{times}

\renewcommand{\normalsize}{\@setfontsize\normalsize\@xiipt\@xivpt}
\newcommand{\XIIIPT}{\@setfontsize\xiiipt{13}{17}}
\newcommand{\XVIPT}{\@setfontsize\xvipt{16}{20}}

% new commands
\newcounter{instn}
\setcounter{instn}{1}
\newcommand{\instnum}{\arabic{instn}}
\newcommand{\inst}[1]{\ensuremath{^{#1}}}
\newcommand{\email}[1]{\\\mbox{}\\[-6pt]\footnotesize\texttt{#1}}
\renewcommand{\and}{, }

% aumenta o espaço entre linhas do documento
\renewcommand{\baselinestretch}{1.5}\small\normalsize

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% data do documento
\newcommand\@mes{}
\newcommand{\mes}[1]{%
	\renewcommand\@mes{#1}
}

\newcommand\@ano{}
\newcommand{\ano}[1]{%
	\renewcommand\@ano{#1}
}

% para o condicional e valores booleanos
\RequirePackage{ifthen}

% macro para mês e ano
\newcommand\@mesExt{%
	\ifthenelse{\equal{\@lingua}{brazilian}}%
    {% português do Brasil
		\ifcase\@mes\or Janeiro\or Fevereiro\or Mar\c{c}o\or 
		Abril\or Maio\or Junho\or Julho\or Agosto\or Setembro\or 
		Outubro\or Novembro\or Dezembro\fi%
    }%
    {% inglês
		\ifcase\@mes\or
		January\or February\or March\or 
		April\or May\or June\or 
		July\or August\or September\or 
		October\or November\or December\fi
    }%
}

\def\orientadorprinc#1{\gdef\@orientadorprinc{#1}}
\def\titorientador#1{\gdef\@titorientador{#1}}
\def\coorientador#1{\gdef\@coorientador{#1}}
\def\primeirocomponente#1{\gdef\@primeirocomponente{#1}}
\def\segundocomponente#1{\gdef\@segundocomponente{#1}}
\def\terceirocomponente#1{\gdef\@terceirocomponente{#1}}

% define se deve criar lista de tabelas
\newif\iftablespage
% define se deve criar lista de figuras
\newif\iffigurespage

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\RequirePackage{graphicx}
% Cria a capa do documento, bem como subsequente páginas que antecedem o resumo
\newcommand{\antesprefacio} {%
	
	\capa
	
	\paginatitulo
}

% Cria o índice
\newcommand{\midprefacio} {%
	\newpage
	\tableofcontents
	\newpage
}%

% Cria lista de tabelas etc
\newcommand{\posprefacio} {%
	\newpage
	\iftablespage
        \listoftables
        \newpage
    \fi
    \iffigurespage
        \listoffigures
        \newpage
    \fi
}%

\def\capa{%
	\begin{figure}
	\centering
	\includegraphics[scale=0.8]{logo.jpg}
	\end{figure}
	% escrevo o título
	% \vspace*{6.8cm}
    \vspace*{1.2cm}
% 	\centering
\begin{center}
	\begin{minipage}[b][5.3cm][c]{10cm}
		
		\def\baselinestretch{1}\normalsize\large\footnotesize
		\ifthenelse{\equal{\@lingua}{brazilian}}%
    	{%
% 			\centering
\begin{center}
% 			a capa usa espaçamento comum
			{\large \textit{\@title} \par}%
			\vspace{0.1cm}
			{\normalsize \textbf{\@author} \par}%
			\vspace{0.1cm}
			{\@mesExt\,\,/ \@ano \par}%
			\vspace{0.5cm}
			{\footnotesize Projeto de pesquisa de Mestrado em Ciência da \\Computação}
			\end{center}
		}%
    	{%
% 			colocar em ingles aqui
		}%
	\end{minipage}
	\end{center}
% 	}
	
	% fecho a página
	\pagebreak}

	
\def\paginaBanca{%
	\begin{center}
		\hrule\vspace{1pt}\hrule\vspace{1ex}
		Faculdade Campo Limpo Paulista\\[3ex]
		\hrule\vspace{1pt}\hrule
	\end{center}
	
	\vfill
	\begin{center}
		\Large\bf\expandafter{\@title}
	\end{center}
	\vspace{.5cm}
	\begin{center}
		{\large\bf\@author}\\[2ex]
		{\small{\@mesExt\,\,/ \@ano \par}}
	\end{center}
	\vfill
	{\bf Banca Examinadora:}
	\begin{itemize}
		\item \@orientadorprinc\ (\@titorientador)
		\item \@primeirocomponente
		\item \@segundocomponente
		\item \@terceirocomponente
	\end{itemize}
	\vfill
	\null\newpage}

\def\paginatitulo{
	\begin{center}
		\Large\bf\expandafter{\@title}
	\end{center}
	\vskip 4cm
	\hfill{\parbox[t]{9cm}{%
		Esse documento corresponde ao Projeto de Pesquisa apresentado à Banca Examinadora para qualificação no curso de Mestrado em Ciência da Computação da Faculdade Campo
Limpo Paulista.
	}} \par
	\vskip 3cm
	\hfill{\parbox[t]{8.35cm}{\centerline{Campo Limpo Paulista, \@date.}}}\par
	\vskip 2.2cm
% 	\hfill{\parbox[t]{8.35cm}{\begin{flushright}{\@orientadorprinc\ (\@titorientador)\ifx\@coorientador\relax\else\\[2.5cm]\@coorientador\fi}\end{flushright}}}\par
	\hfill{\parbox[t]{8.35cm}{\begin{flushright}{\@author\\[2.5cm]\@orientadorprinc\ (\@titorientador)}\end{flushright}}}\par
	\vskip 2cm
	\null\newpage
}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% to avoid [...] in the bibliography
% \item[] instead of \item[\@biblabel{#1}\hfill]
\def\@lbibitem[#1]#2{\item[]\if@filesw
      {\let\protect\noexpand
       \immediate
       \write\@auxout{\string\bibcite{#2}{#1}}}\fi\ignorespaces}
\renewenvironment{thebibliography}[1]
     {\section*{\refname
        \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            %% changed!
               \itemindent -\leftmargin
               \itemsep 6pt
            %%%%%%%%%%%
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


% itens
\setlength\leftmargini   {1.27cm}
\setlength\leftmargin    {\leftmargini}
\setlength\leftmarginii  {\leftmargini}
\setlength\leftmarginiii {\leftmargini}
\setlength\leftmarginiv  {\leftmargini}
\setlength  \labelsep    {.5em}
\setlength  \labelwidth  {\leftmargini}
\addtolength\labelwidth  {-\labelsep}
\def\@listI{\leftmargin\leftmargini
            \parsep 0\p@ \@plus1\p@ \@minus\p@
            \topsep 0\p@ \@plus2\p@ \@minus4\p@
            \itemsep0\p@}
\let\@listi\@listI
\@listi
\def\@listii {\leftmargin\leftmarginii
              \labelwidth\leftmarginii
              \advance\labelwidth-\labelsep
              \topsep    0\p@ \@plus2\p@ \@minus\p@}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
              \topsep    0\p@ \@plus\p@\@minus\p@
              \parsep    \z@
              \partopsep \p@ \@plus\z@ \@minus\p@}


% sections
\renewcommand\section{\@startsection{section}{1}{\z@}%
                       {-6\p@ \@plus -4\p@ \@minus -4\p@}%
                       {0\p@ \@plus 4\p@ \@minus 4\p@}%
                       {\normalfont\XIIIPT\bfseries\boldmath
                        \rightskip=\z@ \@plus 8em\pretolerance=10000 }}

\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                       {-6\p@ \@plus -4\p@ \@minus -4\p@}%
                       {0\p@ \@plus 4\p@ \@minus 4\p@}%
                       {\normalfont\normalsize\bfseries\boldmath
                        \rightskip=\z@ \@plus 8em\pretolerance=10000 }}

\RequirePackage{titlesec}
\titlelabel{\thetitle.\hspace{1ex}}

% first page

\pagestyle{empty}

\newcommand{\authortag}[1]{$^{#1}$}

% \def\@maketitle{\newpage
% 	\makecover % monta a capa
% 	%\null % isso dava um espaco extra antes do title
% 	\begin{center}
% 		\vspace*{-.7cm}
% 		{\XVIPT\bf\@title\par}
% 		\vglue 6pt plus 3pt minus 3pt
% 		{\normalsize
% 		\textbf{\begin{tabular}[t]{c}\@author\end{tabular}}\par}
% 		\vglue 6pt plus 3pt minus 3pt
% 		\vglue 6pt plus 3pt minus 3pt
%    \end{center}\par
% }
% \let\maketitleOLD\maketitle
% \renewcommand{\maketitle}{\maketitleOLD\thispagestyle{empty}}

\renewenvironment{abstract}{%
%       \vspace*{0.1cm}
      \list{}{\advance\topsep by6pt\relax\small
      \leftmargin=0.8cm
      \labelwidth=\z@
      \listparindent=\z@
      \itemindent\listparindent
      \rightmargin\leftmargin}\item[\hskip\labelsep
                                    \bfseries\itshape Abstract.]\itshape}%
      {\endlist\vfill\pagebreak}

\newenvironment{resumo}{%
      \list{}{\advance\topsep by6pt\relax\small
      \leftmargin=0.8cm
      \labelwidth=\z@
      \listparindent=\z@
      \itemindent\listparindent
      \rightmargin\leftmargin}\item[\hskip\labelsep
                                    \bfseries\itshape Resumo.]\itshape}%
      {\endlist}

% pacote para formatação da bibliografia (deve vir ao final do cls)
% harvard hackeado para alinhar as referências.
% \RequirePackage{harvardFac}

\RequirePackage{natbib}
% 
%\bibpunct{[}{]}{,}{a}{}{,}